<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pt_PT">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="watchvideo/ui_about.py" line="63"/>
        <source>About</source>
        <translation type="unfinished">Acerca</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_about.py" line="64"/>
        <source>Credits</source>
        <translation type="unfinished">Créditos</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_about.py" line="65"/>
        <source>License</source>
        <translation type="unfinished">Licencia</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_about.py" line="66"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
    <message>
        <location filename="src/about.py" line="48"/>
        <source>WatchVideo is a small application to play or download videos from various youtube-like sites.
It&apos;s made in PyQt4.</source>
        <translation type="obsolete">WatchVideo es un pequeño programa para reproducir, bajar o convertir videos (para Ogg) de vários sitios tipo youtube.
Está hecho en PyQt4.</translation>
    </message>
    <message>
        <location filename="watchvideo/about.py" line="44"/>
        <source>Version: </source>
        <translation type="unfinished">Versión: </translation>
    </message>
    <message>
        <location filename="watchvideo/about.py" line="37"/>
        <source>

WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
It&apos;s made in PyQt4.</source>
        <translation type="unfinished">

WatchVideo es un pequeño programa para reproducir, bajar o convertir videos (para Ogg) de vários sitios tipo youtube.
Está hecho en PyQt4.</translation>
    </message>
</context>
<context>
    <name>AddVideos</name>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="161"/>
        <source>Add Videos</source>
        <translation type="unfinished">Añadir Videos</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="162"/>
        <source>Paste link(s) here:</source>
        <translation type="unfinished">Pegue aquí los enlaces:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="136"/>
        <source>Check Links</source>
        <translation type="obsolete">Comprobar enlaces</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="165"/>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="167"/>
        <source>Add</source>
        <translation type="unfinished">Añadir</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="168"/>
        <source>Play directly from link(s)</source>
        <translation type="unfinished">Reproducir directamente desde los enlaces</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="169"/>
        <source>Download</source>
        <translation type="unfinished">Descargar</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="170"/>
        <source>Destination Folder:</source>
        <translation type="unfinished">Carpeta destino:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="171"/>
        <source>Choose Folder</source>
        <translation type="unfinished">Elegir carpeta</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="173"/>
        <source>After Download:</source>
        <translation type="unfinished">Después de descargar:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="174"/>
        <source>Do Nothing</source>
        <translation type="unfinished">No hacer nada</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="175"/>
        <source>Play</source>
        <translation type="unfinished">Reproducir</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="176"/>
        <source>Convert to Ogg/Vorbis (audio)</source>
        <translation type="unfinished">Convertir a Ogg/Vorbis (audio)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="177"/>
        <source>Convert to Ogg/Theora (video)</source>
        <translation type="unfinished">Convertir a Ogg/Theora (video)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="178"/>
        <source>Rip Audio</source>
        <translation type="unfinished">Extraer audio del video</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="166"/>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="172"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="171"/>
        <source>Get Links</source>
        <translation type="obsolete">Buscar enlaces</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="164"/>
        <source>Get in high quality, if possible.</source>
        <translation>Buscar en alta calidad, si posible.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="163"/>
        <source>Get Videos</source>
        <translation>Buscar Videos</translation>
    </message>
</context>
<context>
    <name>AddVideosDialog</name>
    <message>
        <location filename="watchvideo/add_videos.py" line="41"/>
        <source>Add</source>
        <translation type="unfinished">Añadir</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="175"/>
        <source>Warning</source>
        <translation type="unfinished">Aviso</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="175"/>
        <source>The given download folder doesn&apos;t exist!</source>
        <translation type="unfinished">La carpeta de descargas no existe!</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="191"/>
        <source>Overwrite</source>
        <translation type="unfinished">Sobreescribir</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="191"/>
        <source>Do you wish to overwrite this file?</source>
        <translation type="unfinished">Desea sobreescribir este archivo?</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="205"/>
        <source>There are no valid links to add!</source>
        <translation type="unfinished">No hay enlaces válidos para añadir!</translation>
    </message>
</context>
<context>
    <name>Gui</name>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="463"/>
        <source>No supported services were found</source>
        <translation type="unfinished">No fue encontrado ningún servicio admitido</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="464"/>
        <source>Close</source>
        <translation type="unfinished">Cerrar</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="466"/>
        <source>Currently checking: </source>
        <translation type="unfinished">Comprobando:</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
        <source>Opening download directory </source>
        <translation type="unfinished">Abriendo la(s) carpeta(s) de descargas</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
        <source>with</source>
        <translation type="unfinished">con</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="130"/>
        <source>Start</source>
        <translation type="unfinished">Comenzar</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="131"/>
        <source>Stop</source>
        <translation type="unfinished">Detener</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="132"/>
        <source>Remove</source>
        <translation type="unfinished">Eliminar</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="133"/>
        <source>Remove and delete file</source>
        <translation type="unfinished">Eliminar y borrar los archivos</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="134"/>
        <source>Open Folder</source>
        <translation type="unfinished">Abrir Carpeta</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="135"/>
        <source>Copy original URL</source>
        <translation type="unfinished">Copiar enlace original</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="516"/>
        <source>Download Finished</source>
        <translation type="unfinished">Descarga Terminada</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="644"/>
        <source>There are still downloads active, do you really want to quit?
(you won&apos;t be able to continue the downloads after quit)</source>
        <translation type="obsolete">Aún existen descargas activas, desea salir?
(no podrá continuar las descargas después de salir)</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="456"/>
        <source>Play</source>
        <translation type="unfinished">Reproducir</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="365"/>
        <source>Ripping audio of</source>
        <translation type="unfinished">Extraendo el audio de</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="366"/>
        <source>Audio Ripped</source>
        <translation type="unfinished">Audio extraedo</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="369"/>
        <source>Converting video:</source>
        <translation type="unfinished">Convertindo el video:</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="370"/>
        <source>Video Converted</source>
        <translation type="unfinished">Video Convertido</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="367"/>
        <source>Error ripping audio</source>
        <translation type="unfinished">Error al extraer el audio</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="371"/>
        <source>Error converting video</source>
        <translation type="unfinished">Error al convertir el video</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="451"/>
        <source>Download</source>
        <translation type="unfinished">Descargar</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="136"/>
        <source>Play local file</source>
        <translation>Reproducir archivo local</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="649"/>
        <source>There are still some tasks active, do you really want to quit?
(you won&apos;t be able to continue them after quitting)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="watchvideo/ui_main.py" line="174"/>
        <source>File</source>
        <translation type="unfinished">Archivo</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="175"/>
        <source>Edit</source>
        <translation type="unfinished">Editar</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="176"/>
        <source>Help</source>
        <translation type="unfinished">Ayuda</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="179"/>
        <source>Add Videos</source>
        <translation type="unfinished">Añadir videos</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="180"/>
        <source>Add one or more links to download or play directly in your favorite mediaplayer.</source>
        <translation type="unfinished">Añadir uno o más enlaces para descargar o reproducir directamente en tu reproductor multimedia favorito.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="181"/>
        <source>Search Browser</source>
        <translation type="unfinished">Buscar en Navegador</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="183"/>
        <source>Clear Completed</source>
        <translation type="unfinished">Limpiar completados</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="184"/>
        <source>About</source>
        <translation type="unfinished">Acerca de</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="185"/>
        <source>Preferences</source>
        <translation type="unfinished">Preferencias</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="186"/>
        <source>Quit</source>
        <translation type="unfinished">Salir</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="172"/>
        <source>Speed</source>
        <translation type="unfinished">Velocidad</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="178"/>
        <source>Shortcut to get the links from the clipboard</source>
        <translation type="unfinished">Atajo para obtener los enlaces del portapapeles</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="182"/>
        <source>Searches open windows and tabs in your browser for flash videos (only Firefox and derivatives are suported)</source>
        <translation type="unfinished">Busca en ventanas y pestañas abiertas en tu navegador por videos en flash (sólo Firefox y derivados son soportados)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="187"/>
        <source>Clipboard</source>
        <translation type="unfinished">Portapapeles</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="188"/>
        <source>Fetch link from the clipboard</source>
        <translation type="unfinished">Buscar enlaces del portapapeles</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="189"/>
        <source>Play</source>
        <translation type="unfinished">Reproducir</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="190"/>
        <source>Shortcut to play the video(s) from the url(s) on the clipboard</source>
        <translation type="unfinished">Atajo para reproducir los videos de los urls en el portapapeles</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="192"/>
        <source>Shortcut to download the video(s) from the url(s) on the clipboard</source>
        <translation type="unfinished">Atajo para descargar los videos de los urls en el portapapeles</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="191"/>
        <source>Download</source>
        <translation type="unfinished">Descargar</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="169"/>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="170"/>
        <source>Size</source>
        <translation type="unfinished">Tamaño</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="171"/>
        <source>Progress</source>
        <translation type="unfinished">Progreso</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="173"/>
        <source>Time Left</source>
        <translation type="unfinished">Tiempo Restante</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="168"/>
        <source>WatchVideo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="177"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="watchvideo/preferences.py" line="183"/>
        <source>Media Player</source>
        <translation>Reproductor Multimedia</translation>
    </message>
    <message>
        <location filename="watchvideo/preferences.py" line="183"/>
        <source>Given media player is not valid</source>
        <translation>El reproductor multimedia elegido no es válido</translation>
    </message>
</context>
<context>
    <name>PreferencesWindow</name>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="182"/>
        <source>Preferences</source>
        <translation type="unfinished">Preferencias</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="184"/>
        <source>Default media player:</source>
        <translation type="unfinished">Reproductor multimedia por defecto:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="182"/>
        <source>Save played or downloaded urls in history</source>
        <translation type="obsolete">Guardar en el historial las URLs reproducidas o descargadas</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="183"/>
        <source>Save permanently (urls will be saved to disk)</source>
        <translation type="obsolete">Guardar permanentemente (las URLs seran guardadas en el disco duro)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="187"/>
        <source>Default download folder:</source>
        <translation type="unfinished">Carpeta de descargas por defecto:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="189"/>
        <source>Default action after download:</source>
        <translation type="unfinished">Acción por defecto después de la descarga:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="190"/>
        <source>Do Nothing</source>
        <translation type="unfinished">No hacer nada</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="191"/>
        <source>Play</source>
        <translation type="unfinished">Reproducir</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="192"/>
        <source>Convert to Ogg/Vorbis (Audio)</source>
        <translation type="unfinished">Convertir a Ogg/Vorbis (Audio)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="193"/>
        <source>Convert to Ogg/Theora (Video)</source>
        <translation type="unfinished">Convertir a Ogg/Theora (Video)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="194"/>
        <source>Rip Audio</source>
        <translation type="unfinished">Extraer audio del video</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="198"/>
        <source>Download Options</source>
        <translation type="unfinished">Opciones de descarga</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="209"/>
        <source>High Quality</source>
        <translation type="obsolete">Alta calidad</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="210"/>
        <source>Low Quality</source>
        <translation type="obsolete">Baja calidad</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="204"/>
        <source>Video Quality</source>
        <translation type="unfinished">Calidad del video</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="205"/>
        <source>Notification Messages</source>
        <translation type="unfinished">Mensajes de notificación</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="206"/>
        <source>The download ends successfully.</source>
        <translation type="unfinished">La descarga terminó con éxito.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="207"/>
        <source>Show a notification message when:</source>
        <translation>Mostrar una notificación cuando:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="194"/>
        <source>The download fails.</source>
        <translation type="obsolete">La descarga falla.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="212"/>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="209"/>
        <source>If you want to use your system&apos;s default way to popup messages you can install &apos;python-notify&apos;. 
In case python-notify isn&apos;t installed, WatchVideo uses baloon tooltips on the tray icon provided by Qt4.</source>
        <translation>Si quieres usar la forma de mostrar mensajens por defecto de tu sistema puedes instalar &apos;python-notify&apos;. 
Si python-notify no estuvier instalado, WatchVideo usa tooltips en la área de notificación, providenciados por Qt4.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="211"/>
        <source>Note:</source>
        <translation>Nota:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="188"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="186"/>
        <source>General</source>
        <translation></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="195"/>
        <source>When double-clicking a completed download:</source>
        <translation>Cuando se ejecuta un doble click en la descarga completada:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="196"/>
        <source>Play Local File</source>
        <translation>Reproducir Archivo Local</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="197"/>
        <source>Open Folder</source>
        <translation>Abrir Carpeta</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="199"/>
        <source>Website</source>
        <translation>Sítio Web</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="201"/>
        <source>All High Quality</source>
        <translation>Todos Alta Calidad</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="202"/>
        <source>All low quality</source>
        <translation>Todos Baja Calidad</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="203"/>
        <source>Mixed</source>
        <translation>Mezclado</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="189"/>
        <source>Note: This is still a work-in-progress so many plugins listed here don&apos;t have support for high quality yet.</source>
        <translation type="obsolete">Nota: Esto es un trabajo en progreso por eso muchos plugins acá listados todavia no tienen soporte para alta calidad.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="208"/>
        <source>An error occurs.</source>
        <translation>Sucede un error.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="183"/>
        <source>Use built-in player.</source>
        <translation>Usar reproductor integrado.</translation>
    </message>
</context>
</TS>
